import { getLeafDeserializer, useRenderLeaf, useOnKeyDownMark } from '@udecode/slate-plugins-common';
import { getSlatePluginOptions } from '@udecode/slate-plugins-core';

const MARK_BOLD = 'bold';
const DEFAULTS_BOLD = {
  hotkey: 'mod+b'
};

const useDeserializeBold = () => editor => {
  const options = getSlatePluginOptions(editor, MARK_BOLD);
  return {
    leaf: getLeafDeserializer(Object.assign({
      type: options.type,
      rules: [{
        nodeNames: ['STRONG']
      }, {
        style: {
          fontWeight: ['600', '700', 'bold']
        }
      }]
    }, options.deserialize))
  };
};

/**
 * Enables support for bold formatting
 */

const useBoldPlugin = () => ({
  pluginKeys: MARK_BOLD,
  renderLeaf: useRenderLeaf(MARK_BOLD),
  deserialize: useDeserializeBold(),
  onKeyDown: useOnKeyDownMark(MARK_BOLD)
});

const MARK_CODE = 'code';
const DEFAULTS_CODE = {
  hotkey: 'mod+e'
};

const useDeserializeCode = () => editor => {
  const options = getSlatePluginOptions(editor, MARK_CODE);
  return {
    leaf: getLeafDeserializer(Object.assign({
      type: options.type,
      rules: [{
        nodeNames: ['CODE']
      }, {
        style: {
          wordWrap: 'break-word'
        }
      }]
    }, options.deserialize))
  };
};

/**
 * Enables support for code formatting
 */

const useCodePlugin = () => ({
  pluginKeys: MARK_CODE,
  renderLeaf: useRenderLeaf(MARK_CODE),
  deserialize: useDeserializeCode(),
  onKeyDown: useOnKeyDownMark(MARK_CODE)
});

const MARK_ITALIC = 'italic';
const DEFAULTS_ITALIC = {
  hotkey: 'mod+i'
};

/**
 * Enables support for italic formatting.
 */

const useItalicPlugin = () => ({
  pluginKeys: MARK_ITALIC,
  renderLeaf: useRenderLeaf(MARK_ITALIC),
  deserialize: useDeserializeCode(),
  onKeyDown: useOnKeyDownMark(MARK_ITALIC)
});

const MARK_UNDERLINE = 'underline';
const DEFAULTS_UNDERLINE = {
  hotkey: 'mod+u'
};

const useDeserializeUnderline = () => editor => {
  const options = getSlatePluginOptions(editor, MARK_UNDERLINE);
  return {
    leaf: getLeafDeserializer(Object.assign({
      type: options.type,
      rules: [{
        nodeNames: ['U']
      }, {
        style: {
          textDecoration: 'underline'
        }
      }]
    }, options.deserialize))
  };
};

const MARK_STRIKETHROUGH = 'strikethrough';
const DEFAULTS_STRIKETHROUGH = {
  hotkey: 'mod+shift+s'
};

/**
 * Enables support for strikethrough formatting.
 */

const useStrikethroughPlugin = () => ({
  pluginKeys: MARK_STRIKETHROUGH,
  renderLeaf: useRenderLeaf(MARK_STRIKETHROUGH),
  deserialize: useDeserializeUnderline(),
  onKeyDown: useOnKeyDownMark(MARK_STRIKETHROUGH)
});

const MARK_SUBSCRIPT = 'subscript';
const DEFAULTS_SUBSCRIPT = {
  hotkey: 'mod+.',
  clear: MARK_SUBSCRIPT
};

/**
 * Enables support for subscript formatting.
 */

const useSubscriptPlugin = () => ({
  pluginKeys: MARK_SUBSCRIPT,
  renderLeaf: useRenderLeaf(MARK_SUBSCRIPT),
  deserialize: useDeserializeUnderline(),
  onKeyDown: useOnKeyDownMark(MARK_SUBSCRIPT)
});

const MARK_SUPERSCRIPT = 'superscript';
const DEFAULTS_SUPERSCRIPT = {
  hotkey: 'mod+,',
  clear: MARK_SUPERSCRIPT
};

/**
 * Enables support for superscript formatting.
 */

const useSuperscriptPlugin = () => ({
  pluginKeys: MARK_SUPERSCRIPT,
  renderLeaf: useRenderLeaf(MARK_SUPERSCRIPT),
  deserialize: useDeserializeUnderline(),
  onKeyDown: useOnKeyDownMark(MARK_SUPERSCRIPT)
});

/**
 * Enables support for underline formatting.
 */

const useUnderlinePlugin = () => ({
  pluginKeys: MARK_UNDERLINE,
  renderLeaf: useRenderLeaf(MARK_UNDERLINE),
  deserialize: useDeserializeUnderline(),
  onKeyDown: useOnKeyDownMark(MARK_UNDERLINE)
});

/**
 * Enables support for basic marks:
 * - Bold
 * - Code
 * - Italic
 * - Strikethrough
 * - Subscript
 * - Superscript
 * - Underline
 */

const useBasicMarkPlugins = () => [useBoldPlugin(), useCodePlugin(), useItalicPlugin(), useStrikethroughPlugin(), useSubscriptPlugin(), useSuperscriptPlugin(), useUnderlinePlugin()];

const useDeserializeItalic = () => editor => {
  const options = getSlatePluginOptions(editor, MARK_ITALIC);
  return {
    leaf: getLeafDeserializer(Object.assign({
      type: options.type,
      rules: [{
        nodeNames: ['EM', 'I']
      }, {
        style: {
          fontStyle: 'italic'
        }
      }]
    }, options.deserialize))
  };
};

const useDeserializeStrikethrough = () => editor => {
  const options = getSlatePluginOptions(editor, MARK_STRIKETHROUGH);
  return {
    leaf: getLeafDeserializer(Object.assign({
      type: options.type,
      rules: [{
        nodeNames: ['S', 'DEL', 'STRIKE']
      }, {
        style: {
          textDecoration: 'line-through'
        }
      }]
    }, options.deserialize))
  };
};

const useDeserializeSubscript = () => editor => {
  const options = getSlatePluginOptions(editor, MARK_SUBSCRIPT);
  return {
    leaf: getLeafDeserializer(Object.assign({
      type: options.type,
      rules: [{
        nodeNames: ['SUB']
      }, {
        style: {
          verticalAlign: 'sub'
        }
      }]
    }, options.deserialize))
  };
};

const useDeserializeSuperscript = () => editor => {
  const options = getSlatePluginOptions(editor, MARK_SUPERSCRIPT);
  return {
    leaf: getLeafDeserializer(Object.assign({
      type: options.type,
      rules: [{
        nodeNames: ['SUP']
      }, {
        style: {
          verticalAlign: 'super'
        }
      }]
    }, options.deserialize))
  };
};

export { DEFAULTS_BOLD, DEFAULTS_CODE, DEFAULTS_ITALIC, DEFAULTS_STRIKETHROUGH, DEFAULTS_SUBSCRIPT, DEFAULTS_SUPERSCRIPT, DEFAULTS_UNDERLINE, MARK_BOLD, MARK_CODE, MARK_ITALIC, MARK_STRIKETHROUGH, MARK_SUBSCRIPT, MARK_SUPERSCRIPT, MARK_UNDERLINE, useBasicMarkPlugins, useBoldPlugin, useCodePlugin, useDeserializeBold, useDeserializeCode, useDeserializeItalic, useDeserializeStrikethrough, useDeserializeSubscript, useDeserializeSuperscript, useDeserializeUnderline, useItalicPlugin, useStrikethroughPlugin, useSubscriptPlugin, useSuperscriptPlugin, useUnderlinePlugin };
//# sourceMappingURL=index.es.js.map
