'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var slatePluginsCommon = require('@udecode/slate-plugins-common');
var slatePluginsCore = require('@udecode/slate-plugins-core');

const MARK_BOLD = 'bold';
const DEFAULTS_BOLD = {
  hotkey: 'mod+b'
};

const useDeserializeBold = () => editor => {
  const options = slatePluginsCore.getSlatePluginOptions(editor, MARK_BOLD);
  return {
    leaf: slatePluginsCommon.getLeafDeserializer(Object.assign({
      type: options.type,
      rules: [{
        nodeNames: ['STRONG']
      }, {
        style: {
          fontWeight: ['600', '700', 'bold']
        }
      }]
    }, options.deserialize))
  };
};

/**
 * Enables support for bold formatting
 */

const useBoldPlugin = () => ({
  pluginKeys: MARK_BOLD,
  renderLeaf: slatePluginsCommon.useRenderLeaf(MARK_BOLD),
  deserialize: useDeserializeBold(),
  onKeyDown: slatePluginsCommon.useOnKeyDownMark(MARK_BOLD)
});

const MARK_CODE = 'code';
const DEFAULTS_CODE = {
  hotkey: 'mod+e'
};

const useDeserializeCode = () => editor => {
  const options = slatePluginsCore.getSlatePluginOptions(editor, MARK_CODE);
  return {
    leaf: slatePluginsCommon.getLeafDeserializer(Object.assign({
      type: options.type,
      rules: [{
        nodeNames: ['CODE']
      }, {
        style: {
          wordWrap: 'break-word'
        }
      }]
    }, options.deserialize))
  };
};

/**
 * Enables support for code formatting
 */

const useCodePlugin = () => ({
  pluginKeys: MARK_CODE,
  renderLeaf: slatePluginsCommon.useRenderLeaf(MARK_CODE),
  deserialize: useDeserializeCode(),
  onKeyDown: slatePluginsCommon.useOnKeyDownMark(MARK_CODE)
});

const MARK_ITALIC = 'italic';
const DEFAULTS_ITALIC = {
  hotkey: 'mod+i'
};

/**
 * Enables support for italic formatting.
 */

const useItalicPlugin = () => ({
  pluginKeys: MARK_ITALIC,
  renderLeaf: slatePluginsCommon.useRenderLeaf(MARK_ITALIC),
  deserialize: useDeserializeCode(),
  onKeyDown: slatePluginsCommon.useOnKeyDownMark(MARK_ITALIC)
});

const MARK_UNDERLINE = 'underline';
const DEFAULTS_UNDERLINE = {
  hotkey: 'mod+u'
};

const useDeserializeUnderline = () => editor => {
  const options = slatePluginsCore.getSlatePluginOptions(editor, MARK_UNDERLINE);
  return {
    leaf: slatePluginsCommon.getLeafDeserializer(Object.assign({
      type: options.type,
      rules: [{
        nodeNames: ['U']
      }, {
        style: {
          textDecoration: 'underline'
        }
      }]
    }, options.deserialize))
  };
};

const MARK_STRIKETHROUGH = 'strikethrough';
const DEFAULTS_STRIKETHROUGH = {
  hotkey: 'mod+shift+s'
};

/**
 * Enables support for strikethrough formatting.
 */

const useStrikethroughPlugin = () => ({
  pluginKeys: MARK_STRIKETHROUGH,
  renderLeaf: slatePluginsCommon.useRenderLeaf(MARK_STRIKETHROUGH),
  deserialize: useDeserializeUnderline(),
  onKeyDown: slatePluginsCommon.useOnKeyDownMark(MARK_STRIKETHROUGH)
});

const MARK_SUBSCRIPT = 'subscript';
const DEFAULTS_SUBSCRIPT = {
  hotkey: 'mod+.',
  clear: MARK_SUBSCRIPT
};

/**
 * Enables support for subscript formatting.
 */

const useSubscriptPlugin = () => ({
  pluginKeys: MARK_SUBSCRIPT,
  renderLeaf: slatePluginsCommon.useRenderLeaf(MARK_SUBSCRIPT),
  deserialize: useDeserializeUnderline(),
  onKeyDown: slatePluginsCommon.useOnKeyDownMark(MARK_SUBSCRIPT)
});

const MARK_SUPERSCRIPT = 'superscript';
const DEFAULTS_SUPERSCRIPT = {
  hotkey: 'mod+,',
  clear: MARK_SUPERSCRIPT
};

/**
 * Enables support for superscript formatting.
 */

const useSuperscriptPlugin = () => ({
  pluginKeys: MARK_SUPERSCRIPT,
  renderLeaf: slatePluginsCommon.useRenderLeaf(MARK_SUPERSCRIPT),
  deserialize: useDeserializeUnderline(),
  onKeyDown: slatePluginsCommon.useOnKeyDownMark(MARK_SUPERSCRIPT)
});

/**
 * Enables support for underline formatting.
 */

const useUnderlinePlugin = () => ({
  pluginKeys: MARK_UNDERLINE,
  renderLeaf: slatePluginsCommon.useRenderLeaf(MARK_UNDERLINE),
  deserialize: useDeserializeUnderline(),
  onKeyDown: slatePluginsCommon.useOnKeyDownMark(MARK_UNDERLINE)
});

/**
 * Enables support for basic marks:
 * - Bold
 * - Code
 * - Italic
 * - Strikethrough
 * - Subscript
 * - Superscript
 * - Underline
 */

const useBasicMarkPlugins = () => [useBoldPlugin(), useCodePlugin(), useItalicPlugin(), useStrikethroughPlugin(), useSubscriptPlugin(), useSuperscriptPlugin(), useUnderlinePlugin()];

const useDeserializeItalic = () => editor => {
  const options = slatePluginsCore.getSlatePluginOptions(editor, MARK_ITALIC);
  return {
    leaf: slatePluginsCommon.getLeafDeserializer(Object.assign({
      type: options.type,
      rules: [{
        nodeNames: ['EM', 'I']
      }, {
        style: {
          fontStyle: 'italic'
        }
      }]
    }, options.deserialize))
  };
};

const useDeserializeStrikethrough = () => editor => {
  const options = slatePluginsCore.getSlatePluginOptions(editor, MARK_STRIKETHROUGH);
  return {
    leaf: slatePluginsCommon.getLeafDeserializer(Object.assign({
      type: options.type,
      rules: [{
        nodeNames: ['S', 'DEL', 'STRIKE']
      }, {
        style: {
          textDecoration: 'line-through'
        }
      }]
    }, options.deserialize))
  };
};

const useDeserializeSubscript = () => editor => {
  const options = slatePluginsCore.getSlatePluginOptions(editor, MARK_SUBSCRIPT);
  return {
    leaf: slatePluginsCommon.getLeafDeserializer(Object.assign({
      type: options.type,
      rules: [{
        nodeNames: ['SUB']
      }, {
        style: {
          verticalAlign: 'sub'
        }
      }]
    }, options.deserialize))
  };
};

const useDeserializeSuperscript = () => editor => {
  const options = slatePluginsCore.getSlatePluginOptions(editor, MARK_SUPERSCRIPT);
  return {
    leaf: slatePluginsCommon.getLeafDeserializer(Object.assign({
      type: options.type,
      rules: [{
        nodeNames: ['SUP']
      }, {
        style: {
          verticalAlign: 'super'
        }
      }]
    }, options.deserialize))
  };
};

exports.DEFAULTS_BOLD = DEFAULTS_BOLD;
exports.DEFAULTS_CODE = DEFAULTS_CODE;
exports.DEFAULTS_ITALIC = DEFAULTS_ITALIC;
exports.DEFAULTS_STRIKETHROUGH = DEFAULTS_STRIKETHROUGH;
exports.DEFAULTS_SUBSCRIPT = DEFAULTS_SUBSCRIPT;
exports.DEFAULTS_SUPERSCRIPT = DEFAULTS_SUPERSCRIPT;
exports.DEFAULTS_UNDERLINE = DEFAULTS_UNDERLINE;
exports.MARK_BOLD = MARK_BOLD;
exports.MARK_CODE = MARK_CODE;
exports.MARK_ITALIC = MARK_ITALIC;
exports.MARK_STRIKETHROUGH = MARK_STRIKETHROUGH;
exports.MARK_SUBSCRIPT = MARK_SUBSCRIPT;
exports.MARK_SUPERSCRIPT = MARK_SUPERSCRIPT;
exports.MARK_UNDERLINE = MARK_UNDERLINE;
exports.useBasicMarkPlugins = useBasicMarkPlugins;
exports.useBoldPlugin = useBoldPlugin;
exports.useCodePlugin = useCodePlugin;
exports.useDeserializeBold = useDeserializeBold;
exports.useDeserializeCode = useDeserializeCode;
exports.useDeserializeItalic = useDeserializeItalic;
exports.useDeserializeStrikethrough = useDeserializeStrikethrough;
exports.useDeserializeSubscript = useDeserializeSubscript;
exports.useDeserializeSuperscript = useDeserializeSuperscript;
exports.useDeserializeUnderline = useDeserializeUnderline;
exports.useItalicPlugin = useItalicPlugin;
exports.useStrikethroughPlugin = useStrikethroughPlugin;
exports.useSubscriptPlugin = useSubscriptPlugin;
exports.useSuperscriptPlugin = useSuperscriptPlugin;
exports.useUnderlinePlugin = useUnderlinePlugin;
//# sourceMappingURL=index.js.map
